==> servicecatalog-model-6.6.2-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServicePlanSpecFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface ClusterServicePlanSpecFluent<A extends ClusterServicePlanSpecFluent<A>> extends Fluent<A>{
  public Boolean getBindable();
  public A withBindable(Boolean bindable);
  public Boolean hasBindable();
  public String getClusterServiceBrokerName();
  public A withClusterServiceBrokerName(String clusterServiceBrokerName);
  public Boolean hasClusterServiceBrokerName();
  
  /**
   * This method has been deprecated, please use method buildClusterServiceClassRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClusterObjectReference getClusterServiceClassRef();
  public ClusterObjectReference buildClusterServiceClassRef();
  public A withClusterServiceClassRef(ClusterObjectReference clusterServiceClassRef);
  public Boolean hasClusterServiceClassRef();
  public A withNewClusterServiceClassRef(String name);
  public ClusterServicePlanSpecFluent.ClusterServiceClassRefNested<A> withNewClusterServiceClassRef();
  public ClusterServicePlanSpecFluent.ClusterServiceClassRefNested<A> withNewClusterServiceClassRefLike(ClusterObjectReference item);
  public ClusterServicePlanSpecFluent.ClusterServiceClassRefNested<A> editClusterServiceClassRef();
  public ClusterServicePlanSpecFluent.ClusterServiceClassRefNested<A> editOrNewClusterServiceClassRef();
  public ClusterServicePlanSpecFluent.ClusterServiceClassRefNested<A> editOrNewClusterServiceClassRefLike(ClusterObjectReference item);
  public A addToDefaultProvisionParameters(String key,Object value);
  public A addToDefaultProvisionParameters(Map<String,Object> map);
  public A removeFromDefaultProvisionParameters(String key);
  public A removeFromDefaultProvisionParameters(Map<String,Object> map);
  public Map<String,Object> getDefaultProvisionParameters();
  public <K,V>A withDefaultProvisionParameters(Map<String,Object> defaultProvisionParameters);
  public Boolean hasDefaultProvisionParameters();
  public String getDescription();
  public A withDescription(String description);
  public Boolean hasDescription();
  public String getExternalID();
  public A withExternalID(String externalID);
  public Boolean hasExternalID();
  public A addToExternalMetadata(String key,Object value);
  public A addToExternalMetadata(Map<String,Object> map);
  public A removeFromExternalMetadata(String key);
  public A removeFromExternalMetadata(Map<String,Object> map);
  public Map<String,Object> getExternalMetadata();
  public <K,V>A withExternalMetadata(Map<String,Object> externalMetadata);
  public Boolean hasExternalMetadata();
  public String getExternalName();
  public A withExternalName(String externalName);
  public Boolean hasExternalName();
  public Boolean getFree();
  public A withFree(Boolean free);
  public Boolean hasFree();
  public A addToInstanceCreateParameterSchema(String key,Object value);
  public A addToInstanceCreateParameterSchema(Map<String,Object> map);
  public A removeFromInstanceCreateParameterSchema(String key);
  public A removeFromInstanceCreateParameterSchema(Map<String,Object> map);
  public Map<String,Object> getInstanceCreateParameterSchema();
  public <K,V>A withInstanceCreateParameterSchema(Map<String,Object> instanceCreateParameterSchema);
  public Boolean hasInstanceCreateParameterSchema();
  public A addToInstanceUpdateParameterSchema(String key,Object value);
  public A addToInstanceUpdateParameterSchema(Map<String,Object> map);
  public A removeFromInstanceUpdateParameterSchema(String key);
  public A removeFromInstanceUpdateParameterSchema(Map<String,Object> map);
  public Map<String,Object> getInstanceUpdateParameterSchema();
  public <K,V>A withInstanceUpdateParameterSchema(Map<String,Object> instanceUpdateParameterSchema);
  public Boolean hasInstanceUpdateParameterSchema();
  public A addToServiceBindingCreateParameterSchema(String key,Object value);
  public A addToServiceBindingCreateParameterSchema(Map<String,Object> map);
  public A removeFromServiceBindingCreateParameterSchema(String key);
  public A removeFromServiceBindingCreateParameterSchema(Map<String,Object> map);
  public Map<String,Object> getServiceBindingCreateParameterSchema();
  public <K,V>A withServiceBindingCreateParameterSchema(Map<String,Object> serviceBindingCreateParameterSchema);
  public Boolean hasServiceBindingCreateParameterSchema();
  public A addToServiceBindingCreateResponseSchema(String key,Object value);
  public A addToServiceBindingCreateResponseSchema(Map<String,Object> map);
  public A removeFromServiceBindingCreateResponseSchema(String key);
  public A removeFromServiceBindingCreateResponseSchema(Map<String,Object> map);
  public Map<String,Object> getServiceBindingCreateResponseSchema();
  public <K,V>A withServiceBindingCreateResponseSchema(Map<String,Object> serviceBindingCreateResponseSchema);
  public Boolean hasServiceBindingCreateResponseSchema();
  public A withBindable();
  public A withFree();
  public interface ClusterServiceClassRefNested<N> extends Nested<N>,ClusterObjectReferenceFluent<ClusterServicePlanSpecFluent.ClusterServiceClassRefNested<N>>{
    public N and();
    public N endClusterServiceClassRef();
    
  }
  
}

==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServicePlanSpecFluent.java <==
package io.fabric8.servicecatalog.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ClusterServicePlanSpecFluent<A extends ClusterServicePlanSpecFluent<A>> extends Fluent<A>{
  public Boolean getBindable();
  public A withBindable(Boolean bindable);
  public Boolean hasBindable();
  public String getClusterServiceBrokerName();
  public A withClusterServiceBrokerName(String clusterServiceBrokerName);
  public Boolean hasClusterServiceBrokerName();
  
  /**
   * This method has been deprecated, please use method buildClusterServiceClassRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClusterObjectReference getClusterServiceClassRef();
  public ClusterObjectReference buildClusterServiceClassRef();
  public A withClusterServiceClassRef(ClusterObjectReference clusterServiceClassRef);
  public Boolean hasClusterServiceClassRef();
  public A withNewClusterServiceClassRef(String name);
  public ClusterServicePlanSpecFluent.ClusterServiceClassRefNested<A> withNewClusterServiceClassRef();
  public ClusterServicePlanSpecFluent.ClusterServiceClassRefNested<A> withNewClusterServiceClassRefLike(ClusterObjectReference item);
  public ClusterServicePlanSpecFluent.ClusterServiceClassRefNested<A> editClusterServiceClassRef();
  public ClusterServicePlanSpecFluent.ClusterServiceClassRefNested<A> editOrNewClusterServiceClassRef();
  public ClusterServicePlanSpecFluent.ClusterServiceClassRefNested<A> editOrNewClusterServiceClassRefLike(ClusterObjectReference item);
  public A addToDefaultProvisionParameters(String key,Object value);
  public A addToDefaultProvisionParameters(Map<String,Object> map);
  public A removeFromDefaultProvisionParameters(String key);
  public A removeFromDefaultProvisionParameters(Map<String,Object> map);
  public Map<String,Object> getDefaultProvisionParameters();
  public <K,V>A withDefaultProvisionParameters(Map<String,Object> defaultProvisionParameters);
  public Boolean hasDefaultProvisionParameters();
  public String getDescription();
  public A withDescription(String description);
  public Boolean hasDescription();
  public String getExternalID();
  public A withExternalID(String externalID);
  public Boolean hasExternalID();
  public A addToExternalMetadata(String key,Object value);
  public A addToExternalMetadata(Map<String,Object> map);
  public A removeFromExternalMetadata(String key);
  public A removeFromExternalMetadata(Map<String,Object> map);
  public Map<String,Object> getExternalMetadata();
  public <K,V>A withExternalMetadata(Map<String,Object> externalMetadata);
  public Boolean hasExternalMetadata();
  public String getExternalName();
  public A withExternalName(String externalName);
  public Boolean hasExternalName();
  public Boolean getFree();
  public A withFree(Boolean free);
  public Boolean hasFree();
  public A addToInstanceCreateParameterSchema(String key,Object value);
  public A addToInstanceCreateParameterSchema(Map<String,Object> map);
  public A removeFromInstanceCreateParameterSchema(String key);
  public A removeFromInstanceCreateParameterSchema(Map<String,Object> map);
  public Map<String,Object> getInstanceCreateParameterSchema();
  public <K,V>A withInstanceCreateParameterSchema(Map<String,Object> instanceCreateParameterSchema);
  public Boolean hasInstanceCreateParameterSchema();
  public A addToInstanceUpdateParameterSchema(String key,Object value);
  public A addToInstanceUpdateParameterSchema(Map<String,Object> map);
  public A removeFromInstanceUpdateParameterSchema(String key);
  public A removeFromInstanceUpdateParameterSchema(Map<String,Object> map);
  public Map<String,Object> getInstanceUpdateParameterSchema();
  public <K,V>A withInstanceUpdateParameterSchema(Map<String,Object> instanceUpdateParameterSchema);
  public Boolean hasInstanceUpdateParameterSchema();
  public A addToServiceBindingCreateParameterSchema(String key,Object value);
  public A addToServiceBindingCreateParameterSchema(Map<String,Object> map);
  public A removeFromServiceBindingCreateParameterSchema(String key);
  public A removeFromServiceBindingCreateParameterSchema(Map<String,Object> map);
  public Map<String,Object> getServiceBindingCreateParameterSchema();
  public <K,V>A withServiceBindingCreateParameterSchema(Map<String,Object> serviceBindingCreateParameterSchema);
  public Boolean hasServiceBindingCreateParameterSchema();
  public A addToServiceBindingCreateResponseSchema(String key,Object value);
  public A addToServiceBindingCreateResponseSchema(Map<String,Object> map);
  public A removeFromServiceBindingCreateResponseSchema(String key);
  public A removeFromServiceBindingCreateResponseSchema(Map<String,Object> map);
  public Map<String,Object> getServiceBindingCreateResponseSchema();
  public <K,V>A withServiceBindingCreateResponseSchema(Map<String,Object> serviceBindingCreateResponseSchema);
  public Boolean hasServiceBindingCreateResponseSchema();
  public A withBindable();
  public A withFree();
  public interface ClusterServiceClassRefNested<N> extends Nested<N>,ClusterObjectReferenceFluent<ClusterServicePlanSpecFluent.ClusterServiceClassRefNested<N>>{
    public N and();
    public N endClusterServiceClassRef();
    
  }
  
}
